Documentation
¶
Overview ¶
Package gnocco is just the root
Index ¶
Constants ¶
const ( // DefaultConfigFile specifies the default filename of the config file DefaultConfigFile = "gnocco.conf" // DefaultLogLevel specifies the log level we handle by default DefaultLogLevel = slog.Debug )
Variables ¶
var ( // Version contains the git hashtag injected by make Version = "N/A" // BuildDate contains the build timestamp injected by make BuildDate = "N/A" )
Functions ¶
func NewHandler ¶
NewHandler allocates an iterative DNS resolver optionally using the given root server as starting point.
Types ¶
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
gnocco
command
Package main is the main executable
|
Package main is the main executable |
|
Package zerolog provides a dumb wrapper for logging to os.Stderr using github.com/rs/zerolog
|
Package zerolog provides a dumb wrapper for logging to os.Stderr using github.com/rs/zerolog |
Click to show internal directories.
Click to hide internal directories.